/*
 * Copyright (C) 2011-2017 Intel Corporation. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *   * Neither the name of Intel Corporation nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#include "sgx_trts.h"
#include "sgx_utils.h"
#include "sgx_eid.h"
#include "error_codes.h"
#include "sgx_ecp_types.h"
#include "sgx_thread.h"
#include "dh_session_protocol.h"
#include "sgx_dh.h"
#include "sgx_tcrypto.h"
#include "LocalAttestationCode_t.h"
#include "sgx_tseal.h"
#include "SymmetricEncryptionBox.h"
#include <map> // for some reason, for memcpy, memset syscalls
#ifndef LOCALATTESTATIONTRUSTED_H
#define LOCALATTESTATIONTRUSTED_H

#ifdef __cplusplus
extern "C" {
#endif

class LocalAttestationTrusted {
  static dh_session_t global_session_info;
  static uint32_t global_session_id;
  static uint32_t one_successful_la_done;
  static sgx_ecc_state_handle_t ecc_state;
  static uint8_t verifier_mr_enclave[32];
  static SymmetricEncryptionBox symmetricEncryptionBoxApache;
  static SymmetricEncryptionBox symmetricEncryptionBoxVerifier;
  static uint8_t apache_mr_signer[32];
  static uint32_t verify_peer_enclave_trust(sgx_dh_session_enclave_identity_t* peer_enclave_identity);
public:
    static uint32_t session_request(sgx_dh_msg1_t *dh_msg1, uint32_t *session_id);
    static uint32_t exchange_report(sgx_dh_msg2_t *dh_msg2, sgx_dh_msg3_t *dh_msg3, uint32_t* session_id);
    static void get_verifier_mr_enclave(uint8_t* op_mr_enclave);
    static void set_apache_mr_signer(uint8_t* ip_mr_signer);
    static uint32_t is_one_successful_la_done(); 
//    LocalAttestationTrusted();
};



#ifdef __cplusplus
}
#endif

#endif
